
.. _section_api:


Section objects
===============

Provides access to section properties such as margins and page orientation.


|Sections| objects
------------------

.. currentmodule:: docx.section

.. autoclass:: Sections
   :members:


|Section| objects
-----------------


.. autoclass:: Section
   :members: 


|_Header| and |_Footer| objects
-------------------------------


.. autoclass:: _Header()
   :inherited-members: 
   :members: 
   :exclude-members: part


.. autoclass:: _Footer()
   :inherited-members: 
   :members: 
   :exclude-members: part
